@@ -65,7 +65,7 @@ try
   if (!config->chroot_directory.empty())
   {
     if (chdir(config->chroot_directory.c_str()) == -1 || chroot(".") == -1)
-      throw system_error(string("cannot change root to '") + config->chroot_directory + "'");
+      throw my_system_error(string("cannot change root to '") + config->chroot_directory + "'");
   }
 
   // Drop super user priviledges.
@@ -75,11 +75,11 @@ try
     if (!config->setgid_group.empty())
     {
       if (setgid(config->setgid_group) == -1)
-        throw system_error("setgid() failed");
+        throw my_system_error("setgid() failed");
     }
     if (!config->setuid_user.empty())
       if (setuid(config->setuid_user) == -1)
-        throw system_error("setuid() failed");
+        throw my_system_error("setuid() failed");
   }
 
 #if 0
@@ -90,7 +90,7 @@ try
     switch (fork())
     {
       case -1:
-        throw system_error("can't fork()");
+        throw my_system_error("can't fork()");
       case 0:
         setsid();
         close(STDIN_FILENO);
